# JWTS
[![Image](https://img.shields.io/pypi/v/jwts.svg)](https://pypi.python.org/pypi/jwts)
[![Image](https://github.com/voldemat/jwts/actions/workflows/python-package.yml/badge.svg)](https://github.com/voldemat/jwts/actions?query=workflow%3Apython-package)
[![Image](https://github.com/voldemat/jwts/actions/workflows/python-publish.yml/badge.svg)](https://github.com/voldemat/jwts/actions?query=workflow%3Apython-publish)
